clc
clear
close all

%--------------------------------------------------------------------------
%   Proposal function q(s)
%--------------------------------------------------------------------------

 

alpha=0.4;

beta=0.96;

delta=0.9;

n = delta*alpha*beta/(1-alpha*beta);

q = @(v,x) 1-exp((-(1-beta)*v+n*log(x)+log(1-x))/(beta*(1-delta)));

h = @(x)((1-beta+delta*beta)/(1-beta)*log(1-x)+delta*alpha*beta/(1-alpha*beta)/(1-beta)*log(x));

r = @(x)((log(1-x)+alpha*beta/(1-alpha*beta)*log(x))/(1-beta));

s_r=alpha*beta;
s_m=alpha*delta*beta/(1-alpha*beta+alpha*delta*beta);
s_o=alpha*delta*beta/((1-beta+delta*beta)*(1-alpha*beta)+alpha*delta*beta);


h_m=h(s_m); 

if (h_m>h(s_r))

    s_t=fsolve(@(x)h(x)-h_m,alpha*beta);

else

    s_t=s_r;

end
 

k_r=s_r^(1/(1-alpha));
k_m=s_m^(1/(1-alpha));
k_o=s_o^(1/(1-alpha));
k_t=s_t^(1/(1-alpha));

grid=linspace(0.98*s_m,1.02*s_r,10000)';

N=size(grid,1);

v_o=(alpha*beta*delta/(1-alpha*beta)*log(s_o)+log(1-s_o)-beta*(1-delta)*log(1-s_o))/(1-beta);
v_m=(alpha*beta*delta/(1-alpha*beta)*log(s_m)+log(1-s_m)-beta*(1-delta)*log(1-s_m))/(1-beta);

v_r_1=(alpha*beta*delta/(1-alpha*beta)*log(s_r)+log(1-s_r)-beta*(1-delta)*log(1-s_r))/(1-beta);
v_r_2=beta*v_r_1+delta*alpha*beta/(1-alpha*beta)*log(s_m)+log(1-s_m)-beta*(1-delta)*log(1-s_r);

  
%--------------------------------------------------------------------------
%   Transition
%--------------------------------------------------------------------------


n_simul=40;

k_simul=zeros(n_simul+1,4);


k_simul(1,:)=k_m;

s_simul=zeros(n_simul+1,4);

s_simul(1,:)=s_m;
s_simul(1,1)=q(v_o,s_m);
s_simul(2:n_simul+1,2)=s_r;
s_simul(2:n_simul+1,3)=s_m;
s_simul(2:n_simul+1,4)=s_t;


for i=1:n_simul
    
    s_simul(i+1,1)=q(v_o,s_simul(i,1));
    
    k_simul(i+1,1)=s_simul(i,1)*k_simul(i,1)^alpha;
    
    k_simul(i+1,2)=s_simul(i,2)*k_simul(i,2)^alpha;
    
    k_simul(i+1,3)=s_simul(i,3)*k_simul(i,3)^alpha;
    
    k_simul(i+1,4)=s_simul(i,4)*k_simul(i,4)^alpha;    
    
end



%========================================================================== 

% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1);

xlim(axes1,[1 16]);
ylim(axes1,[s_m*0.994 s_r*1.01]);
box(axes1,'on');
hold(axes1,'all'); 

% Create multiple lines using matrix input to plot
plot1 = plot(s_simul(:,1:3),'MarkerSize',4,'LineWidth',3,'Color',[0 0 0],...
    'Parent',axes1);
set(plot1(1),'LineWidth',2,'Color',[    0.8500    0.3250    0.0980] );
set(plot1(2),'LineStyle','--','Color',[0    0.4470    0.74100]);
set(plot1(3),'LineStyle','-.');




set(gca,'TickLabelInterpreter', 'latex','FontSize',14);
xticks([1 6  11 16 ])
xticklabels({'0','$$5$$','$$10$$','$$15$$'})
%yticks([])
%xlabel('Time $$t$$','interpreter','latex','FontSize',14);
ylabel('Saving rate $s_t$','interpreter','latex','FontSize',14);


I = legend('Organizational equilibrium', 'Ramsey outcome', 'Markov equilibrium');


set(I,'interpreter','latex'); %set Latex interpreter
set(I,'FontWeight','bold','FontSize',14,'Position',[0.269904288276877 0.273007933220031 0.633202265994603 0.171904765719459]);
set(I,'FontName','Times New Roman');
set(I,'box','Off');

%======================================================================== 

% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1);

xlim(axes1,[1 16]);
%ylim(axes1,[0.22 0.45]);
box(axes1,'on');
hold(axes1,'all'); 

% Create multiple lines using matrix input to plot
plot1 = plot(k_simul(:,1:3),'MarkerSize',4,'LineWidth',3,'Color',[0 0 0],...
    'Parent',axes1);
set(plot1(1),'LineWidth',2,'Color',[    0.8500    0.3250    0.0980] );
set(plot1(2),'LineStyle','--','Color',[0    0.4470    0.74100]);
set(plot1(3),'LineStyle','-.');

 



set(gca,'TickLabelInterpreter', 'latex','FontSize',14);
xticks([1 6  11 16 ])
xticklabels({'0','$$5$$','$$10$$','$$15$$'})
%yticks([])
%xlabel('Time $$t$$','interpreter','latex','FontSize',14);
ylabel('Capital $k_t$','interpreter','latex','FontSize',14);



I = legend('Organizational equilibrium', 'Ramsey outcome', 'Markov equilibrium');


set(I,'interpreter','latex'); %set Latex interpreter
set(I,'FontWeight','bold','FontSize',14,'Position',[0.269904288276877 0.273007933220031 0.633202265994603 0.171904765719459]);
set(I,'FontName','Times New Roman');
set(I,'box','Off');
 
%==========================================================================
V=zeros(n_simul,3);

V(:,1)=v_o;
V(:,2)=v_r_1;
V(1,2)=v_r_2;
V(:,3)=v_m;


% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1);

xlim(axes1,[1 16]);
%ylim(axes1,[0.22 0.45]);
box(axes1,'on');
hold(axes1,'all'); 

% Create multiple lines using matrix input to plot
plot1 = plot([V(:,1:2)-0.03,V(:,3)],'MarkerSize',4,'LineWidth',3,'Color',[0 0 0],...
    'Parent',axes1);
set(plot1(1),'LineWidth',2,'Color',[    0.8500    0.3250    0.0980] );
set(plot1(2),'LineStyle','--','Color',[0    0.4470    0.74100]);
set(plot1(3),'LineStyle','-.');

 



set(gca,'TickLabelInterpreter', 'latex','FontSize',14);
xticks([1 6  11 16 ])
xticklabels({'0','$$5$$','$$10$$','$$15$$'})
%yticks([])
%xlabel('Time $$t$$','interpreter','latex','FontSize',14);
ylabel('Action payoff $V_t$','interpreter','latex','FontSize',14);



I = legend('Organizational equilibrium', 'Ramsey outcome', 'Markov equilibrium');


set(I,'interpreter','latex'); %set Latex interpreter
set(I,'FontWeight','bold','FontSize',14,'Position',[0.269904288276877 0.273007933220031 0.633202265994603 0.171904765719459]);
set(I,'FontName','Times New Roman');
set(I,'box','Off');

%set(gcf,'units','normalized','outerposition',[0 0 0.4 0.4]);

 
%==========================================================================

U=zeros(n_simul,3);


for i=1:n_simul
    
    U(i,1)=alpha*(1-alpha*beta+delta*alpha*beta)/(1-alpha*beta)*log(k_simul(i,1))+V(i,1);
    U(i,2)=alpha*(1-alpha*beta+delta*alpha*beta)/(1-alpha*beta)*log(k_simul(i,2))+V(i,2);
    U(i,3)=alpha*(1-alpha*beta+delta*alpha*beta)/(1-alpha*beta)*log(k_simul(i,3))+V(i,3);
    
end


% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1);

xlim(axes1,[1 16]);
%ylim(axes1,[0.22 0.45]);
box(axes1,'on');
hold(axes1,'all'); 

% Create multiple lines using matrix input to plot
plot1 = plot(U(:,1:3),'MarkerSize',4,'LineWidth',3,'Color',[0 0 0],...
    'Parent',axes1);
set(plot1(1),'LineWidth',2,'Color',[    0.8500    0.3250    0.0980] );
set(plot1(2),'LineStyle','--','Color',[0    0.4470    0.74100]);
set(plot1(3),'LineStyle','-.');

 



set(gca,'TickLabelInterpreter', 'latex','FontSize',14);
xticks([1 6  11 16 ])
xticklabels({'0','$$5$$','$$10$$','$$15$$'})
%yticks([])
%xlabel('Time $$t$$','interpreter','latex','FontSize',14);
ylabel('Total payoff $U_t$','interpreter','latex','FontSize',14);



I = legend('Organizational equilibrium', 'Ramsey outcome', 'Markov equilibrium');


set(I,'interpreter','latex'); %set Latex interpreter
set(I,'FontWeight','bold','FontSize',14,'Position',[0.269904288276877 0.273007933220031 0.633202265994603 0.171904765719459]);
set(I,'FontName','Times New Roman');
set(I,'box','Off');

 



 