clc
clear
close all

global beta alpha gamma m_tau n_tau tau xi V_old grid    

beta=0.9;
alpha=0.36;
gamma=0.5;

 

 
tau_m=1/alpha*gamma/(1+gamma)*(1-alpha*beta);

tau_o=fsolve(@(tau)(alpha*beta-alpha)/(1-(1-tau)*alpha*beta-alpha*tau)+gamma/tau-alpha*beta*(1+gamma)/(1-alpha*beta)/(1-tau),0.5);

q = @(s,tau) log(1-alpha*tau-s)+gamma*log(alpha*tau)+alpha*beta*(1+gamma)/(1-alpha*beta)*log(s);
  
v_o=q((1-tau_o)*alpha*beta,tau_o)/(1-beta);

m_tau=1/(1-beta)*(log(1-(1-tau_o)*alpha*beta-alpha*tau_o)+gamma*log(alpha*tau_o)+alpha*beta*(1+gamma)/(1-alpha*beta)*log((1-tau_o)*alpha*beta));

n_tau=alpha*(1+gamma)/(1-alpha*beta);
 
tau_initial=fsolve(@fun_tau_initial,0.5);

 
x0=[alpha*beta,gamma*alpha];

x1=fsolve(@fun_ss_r,x0);

tau_r=x1(2)/alpha;


%--------------------------------------------------------------------------
%   Ramsey
%--------------------------------------------------------------------------

x0=[alpha*beta,gamma*alpha];

x1=fsolve(@fun_ss_r,x0);

sf=x1(1);
mf=x1(2);

xf=1/beta*sf/(1-sf-mf);

x0=0.2;

x1=fminsearch(@fun_os,x0);

s_o=x1;


n=100;

grid=linspace(0.9*xf,1.02*xf, n)';
 
  
V_old=zeros(n,1);
V_new=zeros(n,1);
g_s=zeros(n,1);
g_x=zeros(n,1);
  

update=1; 

g_m=ones(n,1)*mf;

for loop=1:100 
    
    for i=1:n 
        
        xi=grid(i);  
        
        x0=g_m(i);
        
        [s,v]=fminsearch(@fun_vr,x0);  
        
        V_new(i)=-v;
          
        
        g_s(i)=s;
        
        m=(alpha-xi*(1-s))/(1-xi);
        
        g_m(i)=m;
         
 
        xi_f=g_s(i)/(1-g_s(i)-m)/beta;         
         
        g_x(i)=xi_f;        
        
    end
     
    diff=max(abs(V_new-V_old));
    V_old=V_new*update+V_old*(1-update);
    
end

x0=[sf,mf];

[initial,v0]=fminsearch(@fun_v0,x0);

s_0=initial(1);

m_0=initial(2);

v_0=-v0;

x_0=s_0/(1-s_0-m_0)/beta;

%--------------------------------------------------------------------------
%   Transition
%--------------------------------------------------------------------------

 
k_m=((1-tau_m)*alpha*beta)^(1/(1-alpha)); 

n_simul=16;

k_simul=zeros(n_simul+1,3); 

k_simul(1,:)=k_m;

 
tau_simul=zeros(n_simul,3);
g_simul=zeros(n_simul,3);
c_simul=zeros(n_simul,3);
x_simul=zeros(n_simul+1,1);
s_simul=zeros(n_simul,3);
m_simul=zeros(n_simul,1);
U_simul=zeros(n_simul,3);
V_simul=zeros(n_simul,3);


tau_simul(1,1)=tau_initial;

tau_simul(1,3)=tau_m;




s_simul(1,2)=s_0;
    
x_simul(1)=s_0/(1-s_0-m_0)/beta;  
m_simul(1)=m_0;

tau_simul(1,2) = m_0/alpha;
g_simul(1,2)   = k_simul(1,2)^alpha*m_0;
c_simul(1,2)   = k_simul(1,2)^alpha*(1-m_0-s_0);
k_simul(2,2)   = k_simul(1,2)^alpha*s_0; 
V_simul(1,2)   = v_0;
U_simul(1,2)   = V_simul(1,2)+alpha*beta/(1-alpha*beta)*log(k_simul(1,2));

y=k_simul(1,2).^alpha-c_simul(1,2)-g_simul(1,2)-k_simul(2,2);

for i=2:n_simul    
    
    x_simul(i)=interp1(grid,g_x,x_simul(i-1),'linear','extrap'); 
    
    m_simul(i)=interp1(grid,g_m,x_simul(i-1),'linear','extrap');
    
    s_simul(i,2)=interp1(grid,g_s,x_simul(i-1),'linear','extrap');
    
    k_simul(i+1,2)=s_simul(i,2)*k_simul(i,2)^alpha;
    
    g_simul(i,2)=m_simul(i)*k_simul(i,2)^alpha;
    
    c_simul(i,2)=(1-m_simul(i)-s_simul(i,2))*k_simul(i,2)^alpha;
    
    tau_simul(i,2)=m_simul(i)/alpha;
    
    
    V_simul(i,2)=interp1(grid,V_old,x_simul(i-1),'linear','extrap');
    
    U_simul(i,2)=V_simul(i,2)+alpha*(1+gamma)/(1-alpha*beta)*log(k_simul(i,2));
    
end
    
    






for i=1:n_simul
    
    
    %----------------------------------------------------------------------
    %     Organization
    %----------------------------------------------------------------------
        
    
    tau=tau_simul(i,1);
    
    x_initial=[1-(1-tau)*alpha*beta-alpha*tau,1-(1-tau)*alpha*beta-alpha*tau,tau];
    
    x=fsolve(@fun_tau,x_initial);
    
    tau_simul(i+1,1)=x(3); 
    
    mu_1=x(1);
    
    g_simul(i,1)=tau*k_simul(i,1)^alpha*alpha;
     
    c_simul(i,1)=k_simul(i,1)^alpha*mu_1;
    
    s_simul(i,1)=1-mu_1-alpha*tau;
      
    k_simul(i+1,1)=k_simul(i,1)^alpha-g_simul(i,1)-c_simul(i,1); 
    
    V_simul(i,1)=v_o;
    
    U_simul(i,1)=v_o+alpha*(1+gamma)/(1-alpha*beta)*log(k_simul(i,1));
     
     
    
    %----------------------------------------------------------------------
    %     Markov
    %----------------------------------------------------------------------
    
    
    tau_simul(i+1,3)=tau_m;    
    
    k_simul(i+1,3)=k_m;
    
    
    s_simul(i,3)=(1-tau_m)*alpha*beta;
    
    g_simul(i,3)=tau_m*k_m^alpha*alpha;
    
    
    c_simul(i,3)=k_m^alpha-k_m-g_simul(i,3);
    
    V_simul(i,3)=q((1-tau_m)*alpha*beta,tau_m)/(1-beta);
    
    U_simul(i,3)=alpha*(1+gamma)/(1-alpha*beta)*log(k_m)+V_simul(i,3);
    
    
end

 
 

%-------------------------------------------------------------------------
%   capital
%-------------------------------------------------------------------------




% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1);

xlim(axes1,[1 16]);
%ylim(axes1,[0.22 0.45]);
box(axes1,'on');
hold(axes1,'all'); 

% Create multiple lines using matrix input to plot
plot1 = plot(k_simul(:,1:3),'MarkerSize',4,'LineWidth',3,'Color',[0 0 0],...
    'Parent',axes1);
set(plot1(1),'LineWidth',2,'Color',[    0.8500    0.3250    0.0980] );
set(plot1(2),'LineStyle','--','Color',[0    0.4470    0.74100]);
set(plot1(3),'LineStyle','-.');

 



set(gca,'TickLabelInterpreter', 'latex','FontSize',14);
xticks([1 6  11 16 ])
xticklabels({'0','$$5$$','$$10$$','$$15$$'})
yticks([])
%xlabel('Time $$t$$','interpreter','latex','FontSize',14);
ylabel('Capital $k_t$','interpreter','latex','FontSize',14);




I = legend('Organizational Equilibrium', 'Ramsey Outcome', 'Markov Equilibrium');

set(I,'interpreter','latex'); %set Latex interpreter
set(I,'FontWeight','bold','FontSize',14,'Position',[0.269904288276877 0.273007933220031 0.633202265994603 0.171904765719459]);
set(I,'FontName','Times New Roman');
set(I,'box','Off');
 


%-------------------------------------------------------------------------
%   government spending
%-------------------------------------------------------------------------




% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1);

xlim(axes1,[1 16]);
%ylim(axes1,[0.22 0.45]);
box(axes1,'on');
hold(axes1,'all'); 

% Create multiple lines using matrix input to plot
plot1 = plot(g_simul(:,1:3),'MarkerSize',4,'LineWidth',3,'Color',[0 0 0],...
    'Parent',axes1);
set(plot1(1),'LineWidth',2,'Color',[    0.8500    0.3250    0.0980] );
set(plot1(2),'LineStyle','--','Color',[0    0.4470    0.74100]);
set(plot1(3),'LineStyle','-.');

 



set(gca,'TickLabelInterpreter', 'latex','FontSize',14);
xticks([1 6  11 16 ])
xticklabels({'0','$$5$$','$$10$$','$$15$$'})
yticks([])
%xlabel('Time $$t$$','interpreter','latex','FontSize',14);
ylabel('Government spending $g_t$','interpreter','latex','FontSize',14);




I = legend('Organizational Equilibrium', 'Ramsey Outcome', 'Markov Equilibrium');

set(I,'interpreter','latex'); %set Latex interpreter
set(I,'FontWeight','bold','FontSize',14,'Position',[0.399723169878337 0.563898807616461 0.49079468726452 0.171904765719459]);
set(I,'FontName','Times New Roman');
set(I,'box','Off');

 

%-------------------------------------------------------------------------
%   tax
%-------------------------------------------------------------------------




% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1);

xlim(axes1,[1 16]);
%ylim(axes1,[0.22 0.45]);
box(axes1,'on');
hold(axes1,'all'); 

% Create multiple lines using matrix input to plot
plot1 = plot(tau_simul(:,1:3),'MarkerSize',4,'LineWidth',3,'Color',[0 0 0],...
    'Parent',axes1);
set(plot1(1),'LineWidth',2,'Color',[    0.8500    0.3250    0.0980] );
set(plot1(2),'LineStyle','--','Color',[0    0.4470    0.74100]);
set(plot1(3),'LineStyle','-.');

 



set(gca,'TickLabelInterpreter', 'latex','FontSize',14);
xticks([1 6  11 16 ])
xticklabels({'0','$$5$$','$$10$$','$$15$$'})
yticks([])
%xlabel('Time $$t$$','interpreter','latex','FontSize',14);
ylabel('Tax rate $\tau_t$','interpreter','latex','FontSize',14);




I = legend('Organizational Equilibrium', 'Ramsey Outcome', 'Markov Equilibrium');

set(I,'interpreter','latex'); %set Latex interpreter
set(I,'FontWeight','bold','FontSize',14,'Position',[0.399723169878337 0.563898807616461 0.49079468726452 0.171904765719459]);
set(I,'FontName','Times New Roman');
set(I,'box','Off');

 



%-------------------------------------------------------------------------
%   saving rate
%-------------------------------------------------------------------------




% Create figure
figure1 = figure;

% Create axes
axes1 = axes('Parent',figure1);

xlim(axes1,[1 16]);
%ylim(axes1,[0.22 0.45]);
box(axes1,'on');
hold(axes1,'all'); 

% Create multiple lines using matrix input to plot
plot1 = plot(c_simul(:,1:3),'MarkerSize',4,'LineWidth',3,'Color',[0 0 0],...
    'Parent',axes1);
set(plot1(1),'LineWidth',2,'Color',[    0.8500    0.3250    0.0980] );
set(plot1(2),'LineStyle','--','Color',[0    0.4470    0.74100]);
set(plot1(3),'LineStyle','-.');

 



set(gca,'TickLabelInterpreter', 'latex','FontSize',14);
xticks([1 6  11 16 ])
xticklabels({'0','$$5$$','$$10$$','$$15$$'})
yticks([])
%xlabel('Time $$t$$','interpreter','latex','FontSize',14);
ylabel('Consumption $c_t$','interpreter','latex','FontSize',14);




I = legend('Organizational Equilibrium', 'Ramsey Outcome', 'Markov Equilibrium');

set(I,'interpreter','latex'); %set Latex interpreter
set(I,'FontWeight','bold','FontSize',14,'Position',[0.269904288276877 0.273007933220031 0.633202265994603 0.171904765719459]);
set(I,'FontName','Times New Roman');
set(I,'box','Off');
 
 